==> verve-plugin-0.3.3.tar.bz2: verve-plugin-0.3.3/panel-plugin/verve-history.h <==
/***************************************************************************
 *            verve-history.h
 *
 *  $Id: verve-history.h 1296 2006-04-03 16:10:50Z jpohlmann $
 *  Copyright  2006  Jannis Pohlmann
 *  info@sten-net.de
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __VERVE_HISTORY_H__
#define __VERVE_HISTORY_H__

#include <glib-object.h>

/* Init / Shutdown history database */
void         verve_history_init             (void);
void         verve_history_shutdown         (void);

void         verve_history_add              (gchar *input);
GList       *verve_history_begin            (void);
GList       *verve_history_end              (void);
GList       *verve_history_get_prev         (const GList *current);
GList       *verve_history_get_next         (const GList *current);
gboolean     verve_history_is_empty         (void);
const gchar *verve_history_get_last_command (void);

#endif /* !__VERVE_HISTORY_H__ */

/* vim:set expandtab sts=2 ts=2 sw=2: */

==> verve-plugin-0.3.5.tar.bz2: verve-plugin-0.3.5/panel-plugin/verve-history.h <==
/***************************************************************************
 *            verve-history.h
 *
 *  $Id: verve-history.h 2389 2007-01-16 21:50:16Z jannis $
 *  Copyright  2006-2007  Jannis Pohlmann
 *  jannis@xfce.org
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __VERVE_HISTORY_H__
#define __VERVE_HISTORY_H__

#include <glib-object.h>

/* Init / Shutdown history database */
void         verve_history_init             (void);
void         verve_history_shutdown         (void);

void         verve_history_set_length       (gint         length);
void         verve_history_add              (gchar       *input);
GList       *verve_history_begin            (void);
GList       *verve_history_end              (void);
GList       *verve_history_get_prev         (const GList *current);
GList       *verve_history_get_next         (const GList *current);
gboolean     verve_history_is_empty         (void);
const gchar *verve_history_get_last_command (void);

#endif /* !__VERVE_HISTORY_H__ */

/* vim:set expandtab sts=2 ts=2 sw=2: */
